@@ -9,8 +9,8 @@ __title__ = 'airflow-clickhouse-plugin'
 __description__ = \
     'airflow-clickhouse-plugin - ' \
     'Airflow plugin to execute ClickHouse commands and queries'
-__version__ = '0.8.1'
-__url__ = 'https://github.com/whisklabs/airflow-clickhouse-plugin'
+__version__ = '0.10.0'
+__url__ = 'https://github.com/bryzgaloff/airflow-clickhouse-plugin'
 __license__ = 'MIT License'
-__author__ = 'Anton Bryzgalov, Viktor Taranenko'
-__author_email__ = 'tony.bryzgaloff@gmail.com, viktor@samsungnext.com'
+__author__ = 'Anton Bryzgalov'
+__author_email__ = 'tony.bryzgaloff@gmail.com'
