@@ -1,6 +1,6 @@
 from typing import Dict, Callable, Any, Optional
 
-from airflow.sensors.sql import SqlSensor
+from airflow.providers.common.sql.sensors.sql import SqlSensor
 from airflow.utils.decorators import apply_defaults
 from airflow_clickhouse_plugin.hooks.clickhouse_hook import ClickHouseHook
 
